@@ -72,7 +72,7 @@ if (isset($_POST['weather_view_humidity'])) $weather_view_humidity = $_POST['wea
 if (isset($_POST['weather_view_visibility'])) $weather_view_visibility = $_POST['weather_view_visibility'];
 if (isset($_POST['weather_view_barometer'])) $weather_view_barometer = $_POST['weather_view_barometer'];
 if (isset($_POST['weather_country'])) $weather_country = $_POST['weather_country'];
-if (isset($_POST['weather_cachetime'])) $weather_cachetime = $_POST['weather_cachetime'];
+if (isset($_POST['weather_cachetime'])) $weather_cachetime = $_POST['weather_cachetime'] * 60;
 if (isset($_POST['weather_viewable'])) $weather_viewable = $_POST['weather_viewable'];
 if (isset($_POST['weather_width'])) $weather_width = $_POST['weather_width'];
 if (isset($_POST['weather_margin_right'])) $weather_margin_right = $_POST['weather_margin_right'];
@@ -248,6 +248,44 @@ if (isset ($weather_submit))
 			}
 
 
+
+			// catch 302 redirects
+			//
+			if (!$socketError && strpos($data, 'Location: ') !== FALSE)
+			{
+
+				$explode = explode('Location: ',$data);
+				$explode = explode('Via:',$explode[1]);
+				$data = $explode[0];
+				preg_match("/http:\/\/(.*?)\/(.*)/",$data,$matches);
+				$host = $matches[1];
+				$the_server = $host;
+				$data = '/' . $matches[2];
+				$request  = "GET " . $data . " HTTP/1.0\r\n";
+				$request .= "Host: $host\r\n";
+				$request .= "Accept: */*\r\n";
+				$request .= "Connection: close\r\n";
+				$request .= "\r\n\r\n";
+
+				if ($httpsock = fsockopen ($the_server, 80)) {
+
+					fwrite ($httpsock, $request);
+					$data = "";
+
+					while (!feof($httpsock))
+					{
+						$data .= fread ($httpsock, 1024);
+					}
+					fclose($httpsock);
+				}
+				else
+				{
+					$socketError = 1;
+				}
+
+			}
+
+
         		// US locations
         		//
         		if (!$socketError && empty($weather_country)) 
@@ -255,7 +293,7 @@ if (isset ($weather_submit))
 
 	    			$explode = explode('<td background="/weather/images/fcicons/forecast_blank.jpg" height="57" class="white1">',$data,2);
 	    			$explode = explode('<',$explode[1],2);
-	    			$weather_place = substr($explode[0],2);
+	    			$weather_place = trim($explode[0]);
             			$weather_url = '';
 
 
@@ -963,25 +1001,21 @@ echo '> Zimbabwe</OPTION>
 
                 '<tr>'.
                 '<td align=left width="20%" style="padding-left: 20px;">'.
-                _("Cache Time:").
+                _("Cache Time (min):").
                 '</td>'.
                 '<td width="6%">&nbsp;</td><td align=left width="74%">'.
                 '<input type=text size=10 maxlen=10 name=weather_cachetime value="';
 
         if (isset ($locations[$theid]['cachetime']))
         {
-                echo $locations[$theid]["cachetime"];
+                echo $locations[$theid]["cachetime"] / 60;
         }
-	elseif ($weather_cache_time_minimum <= 3600)
-	{
-		echo "3600";
-	}
 	else
 	{
 		echo $weather_cache_time_minimum;
 	}
 
-        echo    '">'.
+        echo    '"> (' . $weather_cache_time_minimum . ' ' . _("minutes minimum") . ')' .
                 '</td>'.
                 '</tr>'.
 
