@@ -6,7 +6,7 @@
 	Contact  ......  dan@spot.org
 	Home Site  ....  http://www.spot.org/
 	Program  ......  SquirrelMail Plugin - Weather
-	Version  ......  4.1.0
+	Version  ......  4.1.1
 
 *******************************************************************************/
 
@@ -58,4 +58,11 @@ function weather_optpage_register_block ()
 
 }
 
+function weather_version()
+{
+
+   return '4.1.1';
+
+}
+
 ?>
