@@ -6,7 +6,7 @@
 	Contact  ......  dan@spot.org
 	Home Site  ....  http://www.spot.org/
 	Program  ......  SquirrelMail Plugin - Weather
-	Version  ......  4.1.0
+	Version  ......  4.1.1
 
 *******************************************************************************/
 
@@ -89,7 +89,8 @@ function weather_display ($location, $theid)
 {
 	global $color, $left_size, $data_dir, $username, $weather_proxy;
 
-	$cache_time = 1800;
+	//$cache_time = 1800;
+	$cache_time = $location['cachetime'];
 
 	$thetime = time (NULL);
 	$cachetime = $location['timestamp'] + $cache_time;
@@ -117,7 +118,7 @@ if ($cachetime < $thetime)
 
                     preg_match("/http:\/\/(.*?)\/(.*)/", $location['url'], $matches);
                     $host = $matches[1];
-                    $the_server = $host;
+                    if (empty($weather_proxy)) $the_server = $host;
 		    $request  = "GET /" . $matches[2] . " HTTP/1.0\r\n";
                     // Direct call to their CGI: http://weather.noaa.gov/cgi-bin/call_currwx.pl?cccc=RJTT
                 }
@@ -162,7 +163,7 @@ if ($cachetime < $thetime)
 
 		    	$explode = explode('Location: ',$data);
 		    	$explode = explode('Via:',$explode[1]);
-		    	$data = $explode[0];
+		    	$data = trim($explode[0]);
 
 		    	$request  = "GET " . $data . " HTTP/1.0\r\n";
 		    	$request .= "Host: $host\r\n";
@@ -184,6 +185,7 @@ if ($cachetime < $thetime)
 			$data .= fread ($httpsock, 1024);
 		   }
     		   fclose($httpsock);
+
                 }
 		else
 		{
@@ -191,6 +193,44 @@ if ($cachetime < $thetime)
 		}
 
 
+                // catch 302 redirects
+                //
+                if (!$socketError && strpos($data, 'Location: ') !== FALSE)
+                {
+
+                        $explode = explode('Location: ',$data);
+                        $explode = explode('Via:',$explode[1]);
+                        $data = $explode[0];
+                        preg_match("/http:\/\/(.*?)\/(.*)/",$data,$matches);
+                        $host = $matches[1];
+                        $the_server = $host;
+                        $data = '/' . $matches[2];
+                        $request  = "GET " . $data . " HTTP/1.0\r\n";
+                        $request .= "Host: $host\r\n";
+                        $request .= "Accept: */*\r\n";
+                        $request .= "Connection: close\r\n";
+                        $request .= "\r\n\r\n";
+ 
+                        if ($httpsock = fsockopen ($the_server, 80)) {
+
+                           fwrite ($httpsock, $request);
+                           $data = "";
+
+                           while (!feof($httpsock))
+                           {
+                                $data .= fread ($httpsock, 1024);
+                           }
+                           fclose($httpsock);
+                        }
+                        else
+                        {
+                                $socketError = 1;
+                        }
+
+                }
+
+ 
+ 
                 // US locations
                 //
                 if (!$socketError && empty($location['url'])) {
